==> mls-0.2.tar.gz: mls-0.2/lib/drawutil.h <==
///	\file	drawutil.h
///	\brief	Dwaw Util
#ifndef DRAWUTIL_H
#define DRAWUTIL_H

#include <ncurses.h>

#define COLOR(fg, bg) COLOR_PAIR(((fg)<<3)+(bg))	///< COLOR_PAIR 변환 define

namespace MLS {

/// \brief	color entry struct
struct color_entry
{
	int font,		///< font color
		back;		///< background color
	
	/// \brief	기본 생성자
	color_entry() : font(0), back(0) {}
	
	///	\brief	생성자
	///	\param	line	fontcolor와 background color의 값을 가지고 있는 문자열
	color_entry(const std::string &line)
	{
		std::string::size_type p = line.find(',');
		
		if (p != std::string::npos)
		{
			font = atoi(line.substr(0, p).c_str());
			back = atoi(line.substr(p+1).c_str());
		}
		else 
		{
			back = 0;
			font = atoi(line.c_str());
		}
		
	}
	
	///	\brief	operator == 재정의 함수
	/// \param	t	비교할 color_entry
	///	\return	비교 대상과 같은가
	bool operator == (color_entry &t)
	{
		return font==t.font && back==t.back;
	}
	
	///	\brief	operator < 재정의 함수 
	///	\param	t	비교할 color_entry
	///	\return	비교 대상과 크기 비교된 결과
	bool operator < (color_entry &t)
	{
		return font*16+back > t.font*16+t.back;
	}
};

///	\brief	color 지정 및 속성 지정 함수
///	\param	font	font color
///	\param	back	background color
///	\param	win		ncurses window
inline void setcol(int font, int back, WINDOW *win=stdscr)
{
	if ( font >=8 ) wattron(win, A_BOLD);
	if ( back >=8 ) wattron(win, A_BLINK);
	
	wattron(win, COLOR_PAIR( ((font%8) << 3) + (back%8)));
}

///	\brief	color 지정 및 속성 지정 함수
///	\param	p		color_entry
///	\param	win		ncurses window
inline void setcol(color_entry &p, WINDOW *win=stdscr)
{
	if ( p.font >=8 ) wattron(win, A_BOLD);
	if ( p.back >=8 ) wattron(win, A_BLINK);
	
	wattron(win, COLOR_PAIR( ((p.font%8) << 3) + (p.back%8)));
}

///	\brief	color 지정 및 속성 지정 함수(반전)
///	\param	p		color_entry
///	\param	win		ncurses window
inline void setrcol(color_entry &p, WINDOW *win=stdscr)
{
	if ( p.font >=8 ) wattron(win, A_BLINK);
	if ( p.back >=8 ) wattron(win, A_BOLD);
	
	wattron(win, COLOR_PAIR( ((p.back%8) << 3) + (p.font%8)));
}


///	\brief	color 해제 및 속성 해제 함수
///	\param	win		ncurses window
inline void unsetcol(WINDOW *win=stdscr)
{
	wattroff(win, A_BOLD | A_BLINK);	
}

}; // namespace 
#endif

==> mls-0.4.tar.gz: mls-0.4/lib/drawutil.h <==
///	\file	drawutil.h
///	\brief	Dwaw Util
#ifndef DRAWUTIL_H
#define DRAWUTIL_H

#include <ncurses.h>
#include <iostream>

#define COLOR(fg, bg) COLOR_PAIR(((fg)<<3)+(bg))	///< COLOR_PAIR 변환 define

namespace MLS {

/// \brief	color entry struct
class ColorEntry
{
	public:
	int font,		///< font color
		back;		///< background color
	
	/// \brief	기본 생성자
	ColorEntry() : font(0), back(0) {}
	ColorEntry(int f, int b) : font(f), back(b) { }
	
	///	\brief	operator == 재정의 함수
	/// \param	t	비교할 ColorEntry
	///	\return	비교 대상과 같은가
	bool operator == (ColorEntry &t)
	{
		return font==t.font && back==t.back;
	}
	
	///	\brief	operator < 재정의 함수 
	///	\param	t	비교할 ColorEntry
	///	\return	비교 대상과 크기 비교된 결과
	bool operator < (ColorEntry &t)
	{
		return font*16+back > t.font*16+t.back;
	}	
};

///	\brief	color 지정 및 속성 지정 함수
///	\param	font	font color
///	\param	back	background color
///	\param	win		ncurses window
inline void setcol(int font, int back, WINDOW *win=stdscr)
{
	if ( font >=8 ) wattron(win, A_BOLD);
	//if ( back >=8 ) wattron(win, A_BLINK);
	
	wattron(win, COLOR_PAIR( ((font%8) << 3) + (back%8)));
}

///	\brief	color 지정 및 속성 지정 함수
///	\param	p		ColorEntry
///	\param	win		ncurses window
inline void setcol(ColorEntry &p, WINDOW *win=stdscr)
{
	if ( p.font >=8 ) wattron(win, A_BOLD);
	//if ( p.back >=8 ) wattron(win, A_BLINK);
	
	wattron(win, COLOR_PAIR( ((p.font%8) << 3) + (p.back%8)));
}

///	\brief	color 지정 및 속성 지정 함수(반전)
///	\param	p		ColorEntry
///	\param	win		ncurses window
inline void setrcol(ColorEntry &p, WINDOW *win=stdscr)
{
	//if ( p.font >=8 ) wattron(win, A_BLINK);
	if ( p.back >=8 ) wattron(win, A_BOLD);
	
	wattron(win, COLOR_PAIR( ((p.back%8) << 3) + (p.font%8)));
}


///	\brief	color 해제 및 속성 해제 함수
///	\param	win		ncurses window
inline void unsetcol(WINDOW *win=stdscr)
{
	wattroff(win, A_BOLD | A_BLINK);	
}

}; // namespace 
#endif
